/**
 * @file
 */


/**
 * Processing module javascript file to switch between render & source.
 *
 * We can't generate script elements on the fly because in Webkit,
 * Gecko, and IE it will always try to compile the script in JavaScript
 * even when type is NOT text/javascript. This doesn't make any sense.
 *
 * A note on performance. There can be a maximum of 0..n processing
 * instances loaded on a page where n is the number of [processing] tag
 * blocks on the page. This value is always increasing and never
 * decreasing so it is possible for a user to overload themselves for
 * high values of n.
 */
(function($) {

  var instances = new Array;

  Drupal.behaviors.processing = {
    /**
     * Try to invoke Processing.js instance
     */
    invoke: function (canvas) {
      var script = canvas.prev('script');
      var canvas_element = canvas.get(0);

      try {
        instances[canvas.attr('id')] = new Processing(canvas_element, script.get(0).text);
      }
      catch (err) {
        if (canvas.parent().siblings('div.messages').length == 0) {
          canvas.parent().before('<div class="messages error">' + Drupal.t('Syntax Error: ') + err.message + '</div>');
        }

        if (canvas.siblings('pre')) {
          canvas.siblings('.processing-button').attr('value', Drupal.t('Render Sketch'));
          canvas.siblings('pre').show(400);
          canvas.hide(400);
        }
      }
    },

    /**
     * Attach behavior.
     */
    attach: function (context, settings) {

      // Load any visible canvases immediately.
      $('canvas.processing-js-canvas:visible').each(function() {
        if (instances[$(this).attr('id')] === undefined) {
          Drupal.behaviors.processing.invoke($(this));
        }
      });

      // When a Render Sketch or View Source button is clicked show/hide.
      // and try to invoke if rendering.
      $('.processing-button').click(function() {
        if ($(this).attr('value') == Drupal.t('Render Sketch')) {
          var pre = $(this).nextAll('pre');
          var canvas = $(this).nextAll('canvas');

          // Hide/Show
          pre.hide(400);
          canvas.show(400);

          if (instances[canvas.attr('id')] === undefined) {
            Drupal.behaviors.processing.invoke(canvas);
          }
        }
        else {
           $(this).attr('value', Drupal.t('Render Sketch'));
           $(this).nextAll('pre').show(400);
           $(this).nextAll('canvas').hide(400);
        }
      });

    } 
  }


})(jQuery);
